==> nessus-core-1.3.3.tar.gz: nessus-core/nessus/comm.h <==
/* Nessus
 * Copyright (C) 1998 Renaud Deraison
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * In addition, as a special exception, Renaud Deraison
 * gives permission to link the code of this program with any
 * version of the OpenSSL library which is distributed under a
 * license identical to that listed in the included COPYING.OpenSSL
 * file, and distribute linked combinations including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * this file, you may extend this exception to your version of the
 * file, but you are not obligated to do so.  If you do not wish to
 * do so, delete this exception statement from your version.
 */
 
#ifndef _NESSUSC_COMM_H
#define _NESSUSC_COMM_H


int comm_init(int,char*);
int comm_get_pluginlist();
int comm_get_preferences(struct arglist *);
int cli_comm_get_preferences(struct arglist *);
int comm_get_rules(struct arglist *);

int comm_get_plugins();

int comm_send_preferences(struct arglist *);
int comm_send_long_preferences(struct arglist*);
int comm_send_rules(struct arglist *);
void comm_get_preferences_errors(struct arglist *);

harglst * comm_get_sessions();
int comm_server_restores_sessions(struct arglist *);
int comm_server_detached_sessions(struct arglist *);
void comm_delete_session(char*);
void comm_restore_session(char*);
void comm_stop_detached_session( char *name);

int comm_plugin_upload(char*);

#ifdef ENABLE_SAVE_TESTS
harglst * comm_get_detached_sessions(void);
#endif


#endif

==> nessus-core-2.3.1.tar.gz: nessus-core/nessus/comm.h <==
/* Nessus
 * Copyright (C) 1998 Renaud Deraison
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * In addition, as a special exception, Renaud Deraison
 * gives permission to link the code of this program with any
 * version of the OpenSSL library which is distributed under a
 * license identical to that listed in the included COPYING.OpenSSL
 * file, and distribute linked combinations including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * this file, you may extend this exception to your version of the
 * file, but you are not obligated to do so.  If you do not wish to
 * do so, delete this exception statement from your version.
 */
 
#ifndef _NESSUSC_COMM_H
#define _NESSUSC_COMM_H

#include "context.h"

int comm_init(int,char*);
int comm_get_pluginlist();
int comm_get_preferences(struct context *);
int comm_get_rules(struct context *);

int comm_get_plugins(struct context *);

int comm_send_preferences(struct context *);
int comm_send_long_preferences(struct context *);
int comm_send_rules(struct context *);
void comm_get_preferences_errors(struct context*);

harglst * comm_get_sessions();
int comm_server_restores_sessions(struct context *);
int comm_server_detached_sessions(struct context *);
void comm_delete_session(char*);
void comm_restore_session(char*);
void comm_stop_detached_session( char *name);

int comm_plugin_upload(char*);

int comm_get_dependencies(struct context*);

#ifdef ENABLE_SAVE_TESTS
harglst * comm_get_detached_sessions(void);
#endif


#endif
